#version 330

in vec2 ex_TexCoord;
in vec4 ex_Color;

in vec3 ex_Normal;
in vec3 ex_Vertex;

uniform sampler2D tex;

uniform int light;
uniform vec3 lightSource;
uniform vec4 lightAmbient;
uniform vec4 lightDiffuse;
uniform vec4 lightSpecular;

layout(std140) uniform Material
{
    vec4 matAmbient;
    vec4 matDiffuse;
    vec4 matSpecular;
    float matShininess;
};

layout(location = 0) out vec4 fragColor;

void main(void)
{
    if(ex_Color.a <= 0.01)
        discard;

    vec4 pixel = texture(tex, ex_TexCoord);
    if(pixel.a <= 0.01)
        discard;

    if(light == 1)
    {
        vec3 lightDir = normalize(lightSource - ex_Vertex);

        vec3 eye = normalize(lightSource - ex_Vertex);
        vec3 reflected = normalize(reflect(-lightDir, ex_Normal));

        vec4 ambient  = lightAmbient * matAmbient;
        vec4 diffuse  = lightDiffuse * matDiffuse * max(dot(ex_Normal, lightDir), 0.0);
        vec4 specular = lightSpecular * matSpecular * pow(max(dot(reflected, eye), 0.0), matShininess);

        fragColor = pixel * ex_Color * vec4((ambient + diffuse).xyz,1.0) + vec4(specular.xyz,0.0);
    }
    else
        fragColor = pixel * ex_Color;
}
